@@ -91,6 +91,9 @@ typedef struct
   /* If we should inherit the environment when spawning */
   guint spawn_inherit_environ : 1;
 
+  /* If we should inherit stdin from our process */
+  guint inherit_stdin : 1;
+
   /*
    * If we should profile the entire system. Setting this results in pids
    * being ignored. This is primarily useful for UI to toggle on/off the
@@ -114,6 +117,7 @@ G_DEFINE_TYPE_EXTENDED (SysprofLocalProfiler, sysprof_local_profiler, G_TYPE_OBJ
 
 enum {
   PROP_0,
+  PROP_INHERIT_STDIN,
   N_PROPS,
 
   PROP_ELAPSED,
@@ -127,6 +131,15 @@ enum {
   PROP_WHOLE_SYSTEM,
 };
 
+enum {
+  SUBPROCESS_SPAWNED,
+  SUBPROCESS_FINISHED,
+  N_SINGALS,
+};
+
+static GParamSpec *properties [N_PROPS];
+static guint signals [N_SINGALS];
+
 static inline gint
 _g_ptr_array_find (GPtrArray *ar,
                    gpointer   item)
@@ -318,12 +331,16 @@ sysprof_local_profiler_get_property (GObject    *object,
 
   switch (prop_id)
     {
+    case PROP_INHERIT_STDIN:
+      g_value_set_boolean (value, priv->inherit_stdin);
+      break;
+
     case PROP_ELAPSED:
       g_value_set_double (value, priv->timer ? g_timer_elapsed (priv->timer, NULL) : 0.0);
       break;
 
     case PROP_IS_MUTABLE:
-      g_value_set_boolean (value, !(priv->is_starting || priv->is_starting || priv->is_running));
+      g_value_set_boolean (value, !(priv->is_starting || priv->is_stopping || priv->is_running));
       break;
 
     case PROP_IS_RUNNING:
@@ -370,6 +387,10 @@ sysprof_local_profiler_set_property (GObject      *object,
 
   switch (prop_id)
     {
+    case PROP_INHERIT_STDIN:
+      sysprof_local_profiler_set_inherit_stdin (self, g_value_get_boolean (value));
+      break;
+
     case PROP_WHOLE_SYSTEM:
       priv->whole_system = g_value_get_boolean (value);
       break;
@@ -412,6 +433,44 @@ sysprof_local_profiler_class_init (SysprofLocalProfilerClass *klass)
   object_class->get_property = sysprof_local_profiler_get_property;
   object_class->set_property = sysprof_local_profiler_set_property;
 
+  /**
+   * SysprofLocalProfiler::subprocess-spawned:
+   * @self: a #SysprofLocalProfiler
+   * @subprocess: a #GSubprocess
+   *
+   * This signal is emitted when #SysprofLocalProfiler spawns a process.
+   *
+   * Since: 3.46
+   */
+  signals [SUBPROCESS_SPAWNED] =
+    g_signal_new ("subprocess-spawned",
+                  G_TYPE_FROM_CLASS (klass),
+                  G_SIGNAL_RUN_LAST,
+                  0,
+                  NULL, NULL,
+                  NULL,
+                  G_TYPE_NONE, 1, G_TYPE_SUBPROCESS);
+
+  /**
+   * SysprofLocalProfiler::subprocess-finished:
+   * @self: a #SysprofLocalProfiler
+   * @subprocess: a #GSubprocess
+   *
+   * This signal is emitted when #SysprofLocalProfiler has determined that
+   * the subprocess either exited or was terminated by a signal. Use
+   * g_subprocess_get_if_exited() to determine if exited with exit code.
+   *
+   * Since: 3.46
+   */
+  signals [SUBPROCESS_FINISHED] =
+    g_signal_new ("subprocess-finished",
+                  G_TYPE_FROM_CLASS (klass),
+                  G_SIGNAL_RUN_LAST,
+                  0,
+                  NULL, NULL,
+                  NULL,
+                  G_TYPE_NONE, 1, G_TYPE_SUBPROCESS);
+
   g_object_class_override_property (object_class, PROP_ELAPSED, "elapsed");
   g_object_class_override_property (object_class, PROP_IS_MUTABLE, "is-mutable");
   g_object_class_override_property (object_class, PROP_IS_RUNNING, "is-running");
@@ -422,6 +481,24 @@ sysprof_local_profiler_class_init (SysprofLocalProfilerClass *klass)
   g_object_class_override_property (object_class, PROP_SPAWN_INHERIT_ENVIRON, "spawn-inherit-environ");
   g_object_class_override_property (object_class, PROP_WHOLE_SYSTEM, "whole-system");
 
+  /**
+   * SysprofLocalProfiler:inherit-stdin:
+   *
+   * Sets the profiler to inherit stdin from the calling process when spawning
+   * the subprocess. This has no effect if the #SysprofLocalProfiler is not
+   * responsible for spawning the process.
+   *
+   * Since: 3.46
+   */
+  properties [PROP_INHERIT_STDIN] =
+    g_param_spec_boolean ("inherit-stdin",
+                          "Inherit Stdin",
+                          "If stdin of the calling process should be inherited by the spawned process",
+                          FALSE,
+                          (G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+
+  g_object_class_install_properties (object_class, N_PROPS, properties);
+
   g_type_ensure (SYSPROF_TYPE_GJS_SOURCE);
 #ifdef __linux__
   g_type_ensure (SYSPROF_TYPE_HOSTINFO_SOURCE);
@@ -531,6 +608,8 @@ sysprof_local_profiler_wait_cb (GObject      *object,
   if (!g_subprocess_wait_finish (subprocess, result, &error))
     g_warning ("Wait on subprocess failed: %s", error->message);
 
+  g_signal_emit (self, signals[SUBPROCESS_FINISHED], 0, subprocess);
+
   sysprof_local_profiler_stop (SYSPROF_PROFILER (self));
 }
 
@@ -561,8 +640,12 @@ sysprof_local_profiler_start_after_auth (SysprofLocalProfiler *self)
       g_autoptr(GPtrArray) env = g_ptr_array_new_with_free_func (g_free);
       g_autoptr(SysprofSpawnable) spawnable = sysprof_spawnable_new ();
       g_autoptr(GSubprocess) subprocess = NULL;
+      GSubprocessFlags flags = 0;
       GPid pid;
 
+      if (priv->inherit_stdin)
+        flags |= G_SUBPROCESS_FLAGS_STDIN_INHERIT;
+
       if (priv->spawn_inherit_environ)
         {
           gchar **environ_ = g_get_environ ();
@@ -611,12 +694,16 @@ sysprof_local_profiler_start_after_auth (SysprofLocalProfiler *self)
       else
         {
           const gchar *ident = g_subprocess_get_identifier (subprocess);
+
           pid = atoi (ident);
           g_array_append_val (priv->pids, pid);
+
           g_subprocess_wait_async (subprocess,
                                    NULL,
                                    sysprof_local_profiler_wait_cb,
                                    g_object_ref (self));
+
+          g_signal_emit (self, signals[SUBPROCESS_SPAWNED], 0, subprocess);
         }
     }
 
@@ -1090,3 +1177,40 @@ sysprof_local_profiler_new_replay (SysprofCaptureReader *reader)
 
   return SYSPROF_PROFILER (g_steal_pointer (&self));
 }
+
+/**
+ * sysprof_local_profiler_get_inherit_stdin:
+ *
+ * Since: 3.46
+ */
+gboolean
+sysprof_local_profiler_get_inherit_stdin (SysprofLocalProfiler *self)
+{
+  SysprofLocalProfilerPrivate *priv = sysprof_local_profiler_get_instance_private (self);
+
+  g_return_val_if_fail (SYSPROF_IS_LOCAL_PROFILER (self), FALSE);
+
+  return priv->inherit_stdin;
+}
+
+/**
+ * sysprof_local_profiler_set_inherit_stdin:
+ *
+ * Since: 3.46
+ */
+void
+sysprof_local_profiler_set_inherit_stdin (SysprofLocalProfiler *self,
+                                          gboolean              inherit_stdin)
+{
+  SysprofLocalProfilerPrivate *priv = sysprof_local_profiler_get_instance_private (self);
+
+  g_return_if_fail (SYSPROF_IS_LOCAL_PROFILER (self));
+
+  inherit_stdin = !!inherit_stdin;
+
+  if (priv->inherit_stdin != inherit_stdin)
+    {
+      priv->inherit_stdin = inherit_stdin;
+      g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_INHERIT_STDIN]);
+    }
+}
